# TestUfirst v1.1.5

**Project**: TestUfirst
<br>**Version**: 1.1.5
<br>**OS**: OS Independent
<br>**Author**: Irakli Gzirishvili
<br>**Mail**: gziraklirex@gmail.com

**TestUfirst** is a Python command-line interface application. Test Project 1

## Installation

To use **TestUfirst**, follow these steps:

- Open CMD and run the following command to install `pip install testufirst` then restart your CMD
- To check if **TestUfirst** is installed correctly, run the following command `testufirst`

## Commands

These are the available commands you can use:

- `testufirst` - To list available commands
- `testufirst demo (param)` - Test demo method with param